@@ -393,7 +393,7 @@ sub pdiff {
     fcntl($tfh, F_SETFD, 0)
       or die "Can't clear close-on-exec flag on temp filehandle: $!\n";
     my $cwd = Cwd::cwd(); # Save
-    chdir '/dev/fd' or  die "Unable to change working directory: $!";
+    chdir '/proc/self/fd' or  die "Unable to change working directory: $!";
     open(my $patchpipe, '|-', "$patchprog ".fileno($tfh)) ||  die "Unable to open pipe for patch: $!";
     printmsg "Patching $name with $patchprog\n";
     print $patchpipe $diffs;
