@@ -338,7 +338,10 @@ sub import {
 		}
 
 		# copy the ownership of the private directory
-		chown $info[4], $info[5], "$header_dir/$targetfile", "$package_dir/$targetfile";
+		foreach (glob("{$header_dir,$package_dir}/$targetfile")) {
+		    chown($info[4], $info[5], $_) ||
+		      warn "Failed to set ownership for $_. You need to correct this manually\n";
+		}
 	    }
 	    $imported++;
 	}
