@@ -75,9 +75,10 @@ NOTE: the options may change in the future.
 You can feed existing package lists or old apt-cacher logs into the selection
 algorithm by using the -l option above. If the version is omited (eg. for lists
 created with \"dpkg --get-selections\" then the packages may be redownloaded).
-To avoid this, use following one-liner to fake a list with version infos:
+To avoid this, install libdpkg-perl and use following one-liner to fake a list
+with version infos:
 
-dpkg -l | perl -ne 'if(/^(i.|.i)\\s+(\\S+)\\s+(\\S+)/) { print \"\$2_\$3_i386.deb\\n\$2_\$3_all.deb\\n\"}'
+dpkg -l | perl -MDpkg::Arch -ne 'if(/^(i.|.i)\\s+(\\S+)\\s+(\\S+)/) { print \"\$2_\$3_\", Dpkg::Arch::get_host_arch, \".deb\\n\$2_\$3_all.deb\\n\"}'
 
 "; exit 1;};
 
