@@ -11,7 +11,7 @@ use warnings;
 #############################################################################
 ### configuration ###########################################################
 # Include the library for the config file parser
-require('/usr/share/apt-cacher/apt-cacher-lib.pl');
+require('/usr/share/apt-cacher/lib/apt-cacher.pl');
 use POSIX qw(strftime);
 
 
