@@ -38,7 +38,7 @@ local $SIG{$_} = \&sig_handler foreach qw{INT TERM PIPE QUIT HUP SEGV};
 sub db {
     my ($nolock) = @_;
     my $dbfile="$cfg->{cache_dir}/sums.db";
-    debug_message('Init checksum database') if defined &debug_message;
+    debug_message('Init checksum database') if defined &debug_message && $cfg->{debug};
 
     # Serialise enviroment handling
     my $envlock;
@@ -56,7 +56,7 @@ sub db {
 
     my $logfile;
     push (@envargs, (-ErrFile => $logfile, -ErrPrefix => "[$$]")) if open($logfile, '>>', "$cfg->{log_dir}/db.log");
-    debug_message('Create DB environment') if defined &debug_message;
+    debug_message('Create DB environment') if defined &debug_message && $cfg->{debug};
     my $env;
     eval {
 	local $SIG{__DIE__} = 'IGNORE'; # Prevent log verbosity
@@ -86,7 +86,7 @@ sub db {
         close($envlock);
     }
 
-    debug_message('Open database') if defined &debug_message;
+    debug_message('Open database') if defined &debug_message && $cfg->{debug};
     my $dbh = BerkeleyDB::Btree->new(-Filename => $dbfile,
 				     -Flags => DB_CREATE,
 				     -Env => $env)
@@ -245,8 +245,8 @@ sub import_sums {
 	}
     }
 
-    my $dbh = db();
     if (extract_sums($name, $fh, \%temp)) {
+	my $dbh = db();
 	while (my ($filename,$data) = each %temp){
 	    $dbh->db_put($filename,$data) == 0 || warn "db_put $filename, $data failed with $BerkeleyDB::Error" ;
 	}
@@ -262,7 +262,7 @@ sub import_sums {
 # arg: filehandle
 # arg: DB handle
 sub check_sum {
-    my ($name, $fh, $dbh) = @_;
+    my ($name, $fh) = @_;
     return 1 unless $cfg->{checksum};
 
     if (ref $fh ne 'GLOB') {
@@ -282,8 +282,9 @@ sub check_sum {
     }
 
     my $data;
+    my $dbh = db();
     if (my $status = $dbh->db_get($name, $data) != 0) { # Returns 0 on success.
-	debug_message("db_get for $name failed: $status ($BerkeleyDB::Error)");
+	$cfg->{debug} && debug_message("db_get for $name failed: $status ($BerkeleyDB::Error)");
 	return 1;
     }
 
@@ -298,11 +299,11 @@ sub check_sum {
 	    else {
 		$digest = Digest::MD5->new->addfile($fh)->hexdigest;
 	    }
-	    debug_message("Verify $name $_: db $href->{$_}, file $digest");
+	    $cfg->{debug} && debug_message("Verify $name $_: db $href->{$_}, file $digest");
 	    return ($href->{$_} eq $digest);
 	}
     }
-    debug_message("No stored checksum found for $name. Ignoring");
+    $cfg->{debug} && debug_message("No stored checksum found for $name. Ignoring");
     return 1;
 }
 
