@@ -55,7 +55,25 @@ sub read_config {
 		  request_timeout => 30,
 		  return_buffer_size => 1048576, # 1Mb
 		  reverse_path_map => 1,
-		  ubuntu_release_names => join(', ', qw(dapper edgy feisty gutsy hardy intrepid jaunty karmic lucid maverick natty oneiric precise quantal)),
+		  ubuntu_release_names => join(', ', qw(
+							   dapper
+							   edgy
+							   feisty
+							   gutsy
+							   hardy
+							   intrepid
+							   jaunty
+							   karmic
+							   lucid
+							   maverick
+							   natty
+							   oneiric
+							   precise
+							   quantal
+							   raring
+							   saucy
+							   trusty
+						      )),
 		  use_proxy => 0,
 		  use_proxy_auth => 0,
 		  user => $>,
@@ -358,7 +376,7 @@ sub fd_path {
     my ($fh) = @_;
 
     die 'Not a GLOB' unless ref $fh eq 'GLOB';
-    return '/dev/fd/' . $fh->fileno;
+    return '/proc/self/fd/' . $fh->fileno;
 }
 
 # Delete cached files by filehandle
